@@ -1,4 +1,5 @@
 import simplejson as json
+import six
 from .utils import build_where_clause, build_choose_clause
 from .client import QuickBooks
 from .exceptions import QuickbooksException
@@ -50,6 +51,42 @@ class FromJsonMixin(object):
         return obj
 
 
+# Based on http://stackoverflow.com/a/1118038
+def to_dict(obj, classkey=None):
+    """
+    Recursively converts Python object into a dictionary
+    """
+    if isinstance(obj, dict):
+        data = {}
+        for (k, v) in obj.items():
+            data[k] = to_dict(v, classkey)
+        return data
+    elif hasattr(obj, "_ast"):
+        return to_dict(obj._ast())
+    elif hasattr(obj, "__iter__") and not isinstance(obj, str):
+        return [to_dict(v, classkey) for v in obj]
+    elif hasattr(obj, "__dict__"):
+        if six.PY2:
+            data = dict([(key, to_dict(value, classkey))
+                        for key, value in obj.__dict__.iteritems()
+                        if not callable(value) and not key.startswith('_')])
+        else:
+            data = dict([(key, to_dict(value, classkey))
+                        for key, value in obj.__dict__.items()
+                        if not callable(value) and not key.startswith('_')])
+
+        if classkey is not None and hasattr(obj, "__class__"):
+            data[classkey] = obj.__class__.__name__
+        return data
+    else:
+        return obj
+
+
+class ToDictMixin(object):
+    def to_dict(self):
+        return to_dict(self)
+
+
 class ReadMixin(object):
     qbo_object_name = ""
 
@@ -62,6 +99,17 @@ class ReadMixin(object):
         return cls.from_json(json_data[cls.qbo_object_name])
 
 
+class SendMixin(object):
+    def send(self, qb=None):
+        if not qb:
+            qb = QuickBooks()
+
+        end_point = "{0}/{1}/send".format(self.qbo_object_name, self.Id)
+        results = qb.misc_operation(end_point)
+
+        return results
+
+
 class UpdateMixin(object):
     qbo_object_name = ""
 
@@ -80,6 +128,23 @@ class UpdateMixin(object):
         return obj
 
 
+class DeleteMixin(object):
+    qbo_object_name = ""
+
+    def delete(self, qb=None):
+        if not qb:
+            qb = QuickBooks()
+
+        if not self.Id:
+            raise QuickbooksException('Cannot delete unsaved object')
+
+        data = {
+            'Id': self.Id,
+            'SyncToken': self.SyncToken,
+        }
+        return qb.delete_object(self.qbo_object_name, json.dumps(data))
+
+
 class ListMixin(object):
     qbo_object_name = ""
 
@@ -158,6 +223,29 @@ class ListMixin(object):
 
         return obj_list
 
+    @classmethod
+    def count(cls, where_clause="", qb=None):
+        """
+        :param where_clause: QBO SQL where clause (DO NOT include 'WHERE')
+        :param qb:
+        :return: Returns database record count
+        """
+        if not qb:
+            qb = QuickBooks()
+
+        if where_clause:
+            where_clause = "WHERE " + where_clause
+
+        select = "SELECT COUNT(*) FROM {0} {1}".format(
+            cls.qbo_object_name, where_clause, qb=qb)
+
+        json_data = cls.query(select)
+
+        if "totalCount" in json_data["QueryResponse"]:
+            return json_data["QueryResponse"]["totalCount"]
+        else:
+            return None
+
 
 class QuickbooksPdfDownloadable(object):
     qbo_object_name = ""
@@ -169,3 +257,36 @@ class QuickbooksPdfDownloadable(object):
             raise QuickbooksException(
                 "Cannot download {0} when no Id is assigned or if no quickbooks client is passed in".format(
                     self.qbo_object_name))
+
+
+class ObjectListMixin(object):
+    qbo_object_name = ""
+    _object_list = []
+
+    def __iter__(self):
+        return self._object_list.__iter__()
+
+    def __len__(self):
+        return self._object_list.__len__()
+
+    def __contains__(self, item):
+        return self._object_list.__contains__(item)
+
+    def __getitem__(self, key):
+        # if key is of invalid type or value, the list values will raise the error
+        return self._object_list.__getitem__(key)
+
+    def __setitem__(self, key, value):
+        self._object_list.__setitem__(key, value)
+
+    def __delitem__(self, key):
+        self._object_list.__delitem__(key)
+
+    def __reversed__(self):
+        return self._object_list.__reversed__()
+
+    def append(self, value):
+        self._object_list.append(value)
+
+    def pop(self, *args, **kwargs):
+        return self._object_list.pop(*args, **kwargs)
